aboutsummaryrefslogtreecommitdiff
path: root/src/client/linux/minidump_writer/minidump_writer.h
diff options
context:
space:
mode:
authorted.mielczarek <ted.mielczarek@4c0a9323-5329-0410-9bdc-e9ce6186880e>2012-07-19 22:03:39 +0000
committerted.mielczarek <ted.mielczarek@4c0a9323-5329-0410-9bdc-e9ce6186880e>2012-07-19 22:03:39 +0000
commit2f56276fbfe519913845565f178cfa385da93657 (patch)
treef031e25d09fd0ec8bdb7fc8837979ae4f2bf1982 /src/client/linux/minidump_writer/minidump_writer.h
parentAdd some more DWARF ARM register numbers to the DWARF CFI register maps (diff)
downloadbreakpad-2f56276fbfe519913845565f178cfa385da93657.tar.xz
Allow adding extra memory regions to minidump on linux/windows
A=Bill McCloskey <wmccloskey@mozilla.com> R=ted at https://bugzilla.mozilla.org/show_bug.cgi?id=662646 git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@989 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/client/linux/minidump_writer/minidump_writer.h')
-rw-r--r--src/client/linux/minidump_writer/minidump_writer.h17
1 files changed, 15 insertions, 2 deletions
diff --git a/src/client/linux/minidump_writer/minidump_writer.h b/src/client/linux/minidump_writer/minidump_writer.h
index e79eb79b..4ff3b469 100644
--- a/src/client/linux/minidump_writer/minidump_writer.h
+++ b/src/client/linux/minidump_writer/minidump_writer.h
@@ -51,6 +51,16 @@ struct MappingEntry {
// A list of <MappingInfo, GUID>
typedef std::list<MappingEntry> MappingList;
+// These entries store a list of memory regions that the client wants included
+// in the minidump.
+struct AppMemory {
+ AppMemory(void *ptr, size_t length) : ptr(ptr), length(length) {}
+
+ void *ptr;
+ size_t length;
+};
+typedef std::list<AppMemory> AppMemoryList;
+
// Write a minidump to the filesystem. This function does not malloc nor use
// libc functions which may. Thus, it can be used in contexts where the state
// of the heap may be corrupt.
@@ -64,13 +74,16 @@ typedef std::list<MappingEntry> MappingList;
bool WriteMinidump(const char* filename, pid_t crashing_process,
const void* blob, size_t blob_size);
// This overload also allows passing a list of known mappings.
bool WriteMinidump(const char* filename, pid_t crashing_process,
const void* blob, size_t blob_size,
- const MappingList& mappings);
+ const MappingList& mappings,
+ const AppMemoryList& appdata);
bool WriteMinidump(const char* filename,
const MappingList& mappings,
+ const AppMemoryList& appdata,
LinuxDumper* dumper);
} // namespace google_breakpad
@@ -64,13 +74,16 @@ typedef std::list<MappingEntry> MappingList;
bool WriteMinidump(const char* filename, pid_t crashing_process,
const void* blob, size_t blob_size);
-// This overload also allows passing a list of known mappings.
+// This overload also allows passing a list of known mappings and
+// a list of additional memory regions to be included in the minidump.
bool WriteMinidump(const char* filename, pid_t crashing_process,
const void* blob, size_t blob_size,